@@ -156,8 +156,7 @@ class BrailleGenerator(generator.Generator):
             result.append(self.getLocalizedRoleName(obj, role))
         return result
 
-    @staticmethod
-    def getLocalizedRoleName(obj, role=None):
+    def getLocalizedRoleName(self, obj, role=None):
         """Returns the localized name of the given Accessible object; the name
         is suitable to be brailled.
 
